#[non_exhaustive]pub enum DecoderPath {
Starting,
Sequential,
Stored,
DenseMembers,
MarkerAdmission,
MarkerWindow,
Bgzf,
IndexedParallel,
}Expand description
Decoder implementation selected for the current input.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Starting
Input classification has not completed yet.
Sequential
Serial container inflation on the caller or coordinator thread.
Stored
Direct copying of independently indexed stored DEFLATE blocks.
DenseMembers
Independent inflation of densely spaced ordinary gzip members.
MarkerAdmission
Comparing exact and speculative service rates before path selection.
MarkerWindow
The rapidgzip marker/window pipeline for gzip, zlib, or raw DEFLATE.
Bgzf
Independent inflation of indexed BGZF blocks.
IndexedParallel
Plain zlib-rs inflation resumed from caller-supplied index checkpoints.