#[non_exhaustive]pub enum DeflateErrorKind {
InvalidData,
UnexpectedDictionary,
BackendStatus(i32),
Truncated,
Stalled,
TrailingGarbage,
}Expand description
The reason a DEFLATE stream was rejected.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidData
The backend rejected the compressed stream.
UnexpectedDictionary
The stream unexpectedly requested a preset dictionary.
BackendStatus(i32)
The backend returned an unexpected status code.
Truncated
No progress was possible before the end of the compressed input.
Stalled
The decoder made no progress despite having input and output space.
TrailingGarbage
Bytes remained after the final block of a raw DEFLATE stream.