#[non_exhaustive]pub enum IndexingError {
Decode(DecodeError),
Index(IndexError),
}Expand description
Failure of an operation that decodes and builds an index.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Decode(DecodeError)
The compressed input could not be decoded and verified.
Index(IndexError)
The index could not be constructed or finalized.