#[non_exhaustive]pub enum CheckpointKind {
GzipMemberHeader,
GzipMemberDeflate {
header_offset_in_bytes: u64,
},
ZlibHeader,
RawDeflateStart,
DeflateBlock,
}Expand description
How inflation resumes at a checkpoint.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GzipMemberHeader
The offset points at the gzip magic bytes of a complete member.
GzipMemberDeflate
The offset points at raw DEFLATE immediately after a known member header. Keeping the header offset permits full verification while retaining compatibility with raw-DEFLATE index formats.
ZlibHeader
The offset points at the two-byte header of the zlib stream.
RawDeflateStart
The offset points at the first bit of an unwrapped DEFLATE stream.
DeflateBlock
The offset points at the first bit of a raw DEFLATE block.