#[non_exhaustive]pub struct AlphabetShape {
pub code_lengths: Vec<u8>,
pub declared_count: usize,
}Expand description
Shape of one alphabet declared by a dynamic-Huffman block.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code_lengths: Vec<u8>Code length for every symbol in alphabet order, including zero lengths.
declared_count: usizeNumber of code lengths physically declared by the header.
Implementations
Sourceimpl AlphabetShape
impl AlphabetShape
Sourcepub fn used_count(&self) -> usize
pub fn used_count(&self) -> usize
Returns the number of symbols with non-zero code lengths.
Sourcepub fn length_range(&self) -> Option<(u8, u8)>
pub fn length_range(&self) -> Option<(u8, u8)>
Returns the shortest and longest non-zero code lengths.
Sourcepub fn counts_by_length(&self) -> Vec<(u8, usize)>
pub fn counts_by_length(&self) -> Vec<(u8, usize)>
Returns symbol counts grouped by code length, shortest first.