BlockAnalysis

Struct BlockAnalysis 

#[non_exhaustive]
pub struct BlockAnalysis {
Show 21 fields pub stream_index: u64, pub index_in_stream: u64, pub is_final: bool, pub block_type: BlockType, pub compressed_offset_in_bits: u64, pub compressed_data_offset_in_bits: u64, pub uncompressed_offset_in_bytes: u64, pub compressed_size_in_bits: u64, pub uncompressed_size_in_bytes: u64, pub precode: Option<AlphabetShape>, pub distance: Option<AlphabetShape>, pub literal: Option<AlphabetShape>, pub literal_symbols: u64, pub backreference_symbols: u64, pub copied_bytes: u64, pub farthest_backreference: u64, pub window_backreference_count: u64, pub merged_window_backreference_count: u64, pub used_window_symbols: Option<u64>, pub retained_backreferences: Vec<Backreference>, pub omitted_backreference_count: u64,
}
Structural facts for one DEFLATE block.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
stream_index: u64

Zero-based index of the containing stream.

index_in_stream: u64

Zero-based index within the containing stream.

is_final: bool

Whether this is the stream’s final block.

block_type: BlockType

Block encoding.

compressed_offset_in_bits: u64

Absolute compressed bit offset of the three-bit block header.

compressed_data_offset_in_bits: u64

Absolute compressed bit offset after stored-length or Huffman metadata.

uncompressed_offset_in_bytes: u64

Absolute decompressed byte offset of the block’s first output byte.

compressed_size_in_bits: u64

Exact compressed block size, including its header.

uncompressed_size_in_bytes: u64

Exact number of output bytes produced by the block.

precode: Option<AlphabetShape>

Dynamic precode alphabet.

distance: Option<AlphabetShape>

Dynamic distance alphabet.

literal: Option<AlphabetShape>

Dynamic literal/length alphabet.

literal_symbols: u64

Literal symbols decoded from the block.

backreference_symbols: u64

Length/distance symbols decoded from the block.

copied_bytes: u64

Output bytes copied by length/distance symbols.

farthest_backreference: u64

Farthest reach before this block’s first output byte.

window_backreference_count: u64

References whose source begins before this block’s output.

merged_window_backreference_count: u64

Deterministic interval-union count for those references.

used_window_symbols: Option<u64>

Covered predecessor-window bytes for blocks producing at least 32 KiB.

retained_backreferences: Vec<Backreference>

Detailed references retained within AnalyzeOptions’ global budget.

omitted_backreference_count: u64

Detailed references omitted after the global budget was exhausted.